function makeVideoAndImage(vidname, picname, directory)   
%function makeVideoAndImage(vidname, picname)

    if nargin < 3
        directory = '~/Desktop/vid/';
    end
    
    % Make sure that the directory name ends in a /
    if ~strcmp(directory(end), '/')
        directory = [directory '/'];
    end
    
    % Find images
    dirlist = dir(sprintf('%s*.jpg', directory));
    
    % Make sure folder exists and is not empty
    if ~exist(directory, 'dir')
        error('The folder %s does not exist', directory(1:end-1))
    end
    if isempty(dirlist)
        error('The folder %s does not contain any .jpg images', directory(1:end-1))
    end
    
    % Sort by date of creation to avoid strange stitching behavior
    S = [dirlist(:).datenum].';
    [~, S] = sort(S);
    dirlist = dirlist(S);

    % Initialize long exposure image
    I = imread([directory dirlist(1).name]);
    
    % Initialize video
    aviobj = avifile([vidname '.avi']);
    skip = 10;

    % Build up image and video
    timer = CTimeleft(length(dirlist));
    for i=1:length(dirlist)
        timer.timeleft();
        I=max(I.*uint8(I>175), imread([directory dirlist(i).name]));
        if(~mod(i,skip))
             aviobj = addframe(aviobj, I);
        end
    end
    
    % Save video
     aviobj = close(aviobj);
    
    % Compress video
    if strcmp(computer,'GLNX86')||strcmp(computer,'GLNXA64')
        if exist(sprintf('%s.avi', vidname), 'file')
            delete(sprintf('%s.avi', vidname))
        end
    
        [stat,result] = system(sprintf('ffmpeg -sameq -i temp.avi %s.avi\n', vidname)) % compress the video
        if stat == 0
            delete('temp.avi');
        else
            warning('FFMPEG is either not installed or not correctly configured. Cannot compress AVI.');
        end
    else
        warning('You are not running this on a Linux machine. This m-file is not set up to compress the resulting AVI on Windows. Please find alternative means to compress the file.');
    end
    % Save and display long exposure image
    imwrite(I, sprintf('%s.jpg', picname), 'jpg');
    figure()
    imshow(I)

end
