function makeVideoAndImage(vidname, picname, directory)   
%function makeVideoAndImage(vidname, picname)

    if nargin < 3
        directory = '~/Desktop/vid/';
    end
    
    % Make sure that the directory name ends in a /
    if ~strcmp(directory(end), '/')
        directory = [directory '/'];
    end
    
    % Find images
    dirlist = dir(sprintf('%s*.jpg', directory));
    
    % Make sure folder exists and is not empty
    if ~exist(directory, 'dir')
        error('The folder %s does not exist', directory(1:end-1))
    end
    if isempty(dirlist)
        error('The folder %s does not contain any .jpg images', directory(1:end-1))
    end
    
    % Sort by date of creation to avoid strange stitching behavior
    S = [dirlist(:).datenum].';
    [~, S] = sort(S);
    dirlist = dirlist(S);

    % Initialize long exposure image
    I = imread([directory dirlist(1).name]);
    
    % Initialize video
    aviobj = VideoWriter([vidname '.avi'], 'Motion JPEG AVI');
    open(aviobj);
    skip = 10;

    % Build up image and video
    timer = CTimeleft(length(dirlist));
    for i=1:length(dirlist)
        timer.timeleft();
        I=max(I.*uint8(I>175), imread([directory dirlist(i).name]));
        if(~mod(i,skip))
            writeVideo(aviobj, I);
        end
    end
    
    close(aviobj);
    
    % Save and display long exposure image
    imwrite(I, sprintf('%s.jpg', picname), 'jpg');
    figure()
    imshow(I)

end
